<no title> — cis_interface 0.3.0 documentation

Model YAML:

     1
     2
     3
     4
     5
     6
     7
     8
     9
    10
    11
    12
    13
    14
    models:
      - name: python_model
        language: python  # Runs the python script using default Python
        args: ./src/gs_lesson3.py
        inputs:
          - input
        outputs:
          - output

    connections:
      - input_file: ./Input/input.txt
        output: input
      - input: output
        output: ./output.txt

(Example in other languages)